@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
@@ -129,6 +132,42 @@ class CloudBuildAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return CloudBuildClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> CloudBuildTransport:
         """Returns the transport used by the client instance.
@@ -205,6 +244,30 @@ class CloudBuildAsyncClient:
         the build ID. Pass the build ID to ``GetBuild`` to determine the
         build status (such as ``SUCCESS`` or ``FAILURE``).
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_create_build():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.CreateBuildRequest(
+                    project_id="project_id_value",
+                )
+
+                # Make the request
+                operation = client.create_build(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.CreateBuildRequest, dict]):
                 The request object. Request to create a new build.
@@ -256,7 +319,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, build])
         if request is not None and has_flattened_params:
@@ -312,6 +375,27 @@ class CloudBuildAsyncClient:
         ``SUCCESS``, ``FAILURE``, or ``WORKING``), and timing
         information.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_get_build():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.GetBuildRequest(
+                    project_id="project_id_value",
+                    id="id_value",
+                )
+
+                # Make the request
+                response = client.get_build(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.GetBuildRequest, dict]):
                 The request object. Request to get a build.
@@ -359,7 +443,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, id])
         if request is not None and has_flattened_params:
@@ -415,6 +499,27 @@ class CloudBuildAsyncClient:
         Previously requested builds may still be in-progress, or
         may have finished successfully or unsuccessfully.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_list_builds():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.ListBuildsRequest(
+                    project_id="project_id_value",
+                )
+
+                # Make the request
+                page_result = client.list_builds(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.ListBuildsRequest, dict]):
                 The request object. Request to list builds.
@@ -445,7 +550,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, filter])
         if request is not None and has_flattened_params:
@@ -505,6 +610,26 @@ class CloudBuildAsyncClient:
     ) -> cloudbuild.Build:
         r"""Cancels a build in progress.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_cancel_build():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.CancelBuildRequest(
+                    project_id="project_id_value",
+                    id="id_value",
+                )
+
+                # Make the request
+                response = client.cancel_build(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.CancelBuildRequest, dict]):
                 The request object. Request to cancel an ongoing build.
@@ -552,7 +677,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, id])
         if request is not None and has_flattened_params:
@@ -625,6 +750,31 @@ class CloudBuildAsyncClient:
            available depending on the bucket's lifecycle management
            settings.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_retry_build():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.RetryBuildRequest(
+                    project_id="project_id_value",
+                    id="id_value",
+                )
+
+                # Make the request
+                operation = client.retry_build(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.RetryBuildRequest, dict]):
                 The request object. Specifies a build to retry.
@@ -678,7 +828,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, id])
         if request is not None and has_flattened_params:
@@ -734,6 +884,30 @@ class CloudBuildAsyncClient:
 
         If rejected, the returned LRO will be immediately done.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_approve_build():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.ApproveBuildRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.approve_build(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.ApproveBuildRequest, dict]):
                 The request object. Request to approve or reject a
@@ -788,7 +962,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name, approval_result])
         if request is not None and has_flattened_params:
@@ -848,6 +1022,30 @@ class CloudBuildAsyncClient:
 
         This API is experimental.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_create_build_trigger():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                trigger = cloudbuild_v1.BuildTrigger()
+                trigger.autodetect = True
+
+                request = cloudbuild_v1.CreateBuildTriggerRequest(
+                    project_id="project_id_value",
+                    trigger=trigger,
+                )
+
+                # Make the request
+                response = client.create_build_trigger(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.CreateBuildTriggerRequest, dict]):
                 The request object. Request to create a new
@@ -878,7 +1076,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, trigger])
         if request is not None and has_flattened_params:
@@ -924,6 +1122,27 @@ class CloudBuildAsyncClient:
 
         This API is experimental.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_get_build_trigger():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.GetBuildTriggerRequest(
+                    project_id="project_id_value",
+                    trigger_id="trigger_id_value",
+                )
+
+                # Make the request
+                response = client.get_build_trigger(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.GetBuildTriggerRequest, dict]):
                 The request object. Returns the `BuildTrigger` with the
@@ -956,7 +1175,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, trigger_id])
         if request is not None and has_flattened_params:
@@ -1011,6 +1230,27 @@ class CloudBuildAsyncClient:
 
         This API is experimental.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_list_build_triggers():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.ListBuildTriggersRequest(
+                    project_id="project_id_value",
+                )
+
+                # Make the request
+                page_result = client.list_build_triggers(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.ListBuildTriggersRequest, dict]):
                 The request object. Request to list existing
@@ -1037,7 +1277,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id])
         if request is not None and has_flattened_params:
@@ -1097,6 +1337,24 @@ class CloudBuildAsyncClient:
 
         This API is experimental.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_delete_build_trigger():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.DeleteBuildTriggerRequest(
+                    project_id="project_id_value",
+                    trigger_id="trigger_id_value",
+                )
+
+                # Make the request
+                client.delete_build_trigger(request=request)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.DeleteBuildTriggerRequest, dict]):
                 The request object. Request to delete a `BuildTrigger`.
@@ -1119,7 +1377,7 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, trigger_id])
         if request is not None and has_flattened_params:
@@ -1175,6 +1433,31 @@ class CloudBuildAsyncClient:
 
         This API is experimental.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_update_build_trigger():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                trigger = cloudbuild_v1.BuildTrigger()
+                trigger.autodetect = True
+
+                request = cloudbuild_v1.UpdateBuildTriggerRequest(
+                    project_id="project_id_value",
+                    trigger_id="trigger_id_value",
+                    trigger=trigger,
+                )
+
+                # Make the request
+                response = client.update_build_trigger(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.UpdateBuildTriggerRequest, dict]):
                 The request object. Request to update an existing
@@ -1210,7 +1493,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, trigger_id, trigger])
         if request is not None and has_flattened_params:
@@ -1257,6 +1540,30 @@ class CloudBuildAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Runs a ``BuildTrigger`` at a particular source revision.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_run_build_trigger():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.RunBuildTriggerRequest(
+                    project_id="project_id_value",
+                    trigger_id="trigger_id_value",
+                )
+
+                # Make the request
+                operation = client.run_build_trigger(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.RunBuildTriggerRequest, dict]):
                 The request object. Specifies a build trigger to run and
@@ -1314,7 +1621,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([project_id, trigger_id, source])
         if request is not None and has_flattened_params:
@@ -1367,6 +1674,25 @@ class CloudBuildAsyncClient:
         r"""ReceiveTriggerWebhook [Experimental] is called when the API
         receives a webhook request targeted at a specific trigger.
 
+
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_receive_trigger_webhook():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.ReceiveTriggerWebhookRequest(
+                )
+
+                # Make the request
+                response = client.receive_trigger_webhook(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.ReceiveTriggerWebhookRequest, dict]):
                 The request object. ReceiveTriggerWebhookRequest
@@ -1414,6 +1740,30 @@ class CloudBuildAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a ``WorkerPool``.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_create_worker_pool():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.CreateWorkerPoolRequest(
+                    parent="parent_value",
+                    worker_pool_id="worker_pool_id_value",
+                )
+
+                # Make the request
+                operation = client.create_worker_pool(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.CreateWorkerPoolRequest, dict]):
                 The request object. Request to create a new
@@ -1472,7 +1822,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, worker_pool, worker_pool_id])
         if request is not None and has_flattened_params:
@@ -1531,6 +1881,25 @@ class CloudBuildAsyncClient:
     ) -> cloudbuild.WorkerPool:
         r"""Returns details of a ``WorkerPool``.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_get_worker_pool():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.GetWorkerPoolRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_worker_pool(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.GetWorkerPoolRequest, dict]):
                 The request object. Request to get a `WorkerPool` with
@@ -1569,7 +1938,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1626,6 +1995,29 @@ class CloudBuildAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a ``WorkerPool``.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_delete_worker_pool():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.DeleteWorkerPoolRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                operation = client.delete_worker_pool(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.DeleteWorkerPoolRequest, dict]):
                 The request object. Request to delete a `WorkerPool`.
@@ -1663,7 +2055,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -1719,6 +2111,28 @@ class CloudBuildAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates a ``WorkerPool``.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_update_worker_pool():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.UpdateWorkerPoolRequest(
+                )
+
+                # Make the request
+                operation = client.update_worker_pool(request=request)
+
+                print("Waiting for operation to complete...")
+
+                response = operation.result()
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.UpdateWorkerPoolRequest, dict]):
                 The request object. Request to update a `WorkerPool`.
@@ -1769,7 +2183,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([worker_pool, update_mask])
         if request is not None and has_flattened_params:
@@ -1828,6 +2242,26 @@ class CloudBuildAsyncClient:
     ) -> pagers.ListWorkerPoolsAsyncPager:
         r"""Lists ``WorkerPool``\ s.
 
+        .. code-block:: python
+
+            from google.cloud.devtools import cloudbuild_v1
+
+            def sample_list_worker_pools():
+                # Create a client
+                client = cloudbuild_v1.CloudBuildClient()
+
+                # Initialize request argument(s)
+                request = cloudbuild_v1.ListWorkerPoolsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_worker_pools(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsRequest, dict]):
                 The request object. Request to list `WorkerPool`\s.
@@ -1854,7 +2288,7 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
